@@ -6,7 +6,6 @@ from fastapi import Depends
 from . import constants
 from .backends import CacheBackendBase
 from .dependencies import ResponseCacheDependency
-from .exceptions import NoBackendConfigured
 
 __all__ = ("CacheManager",)
 
@@ -16,7 +15,7 @@ logger = logging.getLogger(__name__)
 class CacheManager:
     def __init__(
         self,
-        backend: CacheBackendBase = None,
+        backend: CacheBackendBase,
         *,
         ttl: int = constants.DEFAULT_TTL,
         no_cache_query_param: str = "no-cache",
@@ -26,14 +25,8 @@ class CacheManager:
         self._no_cache_query_param = no_cache_query_param
 
     def setup(
-        self,
-        backend: CacheBackendBase = None,
-        *,
-        ttl: int = None,
-        no_cache_query_param: str = None,
+        self, *, ttl: int = None, no_cache_query_param: str = None,
     ):
-        if backend is not None:
-            self._backend = backend
         if ttl is not None:
             self._ttl = ttl
         if no_cache_query_param is not None:
@@ -41,8 +34,6 @@ class CacheManager:
 
     @property
     def backend(self) -> CacheBackendBase:
-        if self._backend is None:
-            raise NoBackendConfigured()
         return self._backend
 
     def from_request(self, ttl: int = None) -> Depends:
